@@ -129,13 +129,13 @@ class paymentOperator extends entityDatabaseOperator{
         return $results;
     }
 
-    public function getLatestPaymentsViewData($userEntity=null, $limit=10)
+    public function getLatestPaymentsViewData($userEntity=null, $remoteOrderId=0, $limit=10)
     {
         $currentUser = currentUser::getCurrentUser();
 
         $this->vault
             ->select($this->dbTable . ' p')
-            ->fields('p.id, DATE_FORMAT(FROM_UNIXTIME(p.created), "%D %b %Y") as paymentDate, TRIM(CONCAT(u.first_name, " ", u.last_name)) as customerName, p.amount, p.status, i.line_items as lineItems, i.remote_order_id, p.provider')
+            ->fields('p.id, DATE_FORMAT(FROM_UNIXTIME(p.created), "%D %b %Y at %H:%i") as paymentDate, TRIM(CONCAT(u.first_name, " ", u.last_name)) as customerName, p.amount, p.status, i.line_items as lineItems, i.remote_order_id, p.provider, p.failure_reason, p.fraudulent, p.risk_level')
             ->leftjoin('invoice_payment ip', 'ip.payment_id', 'p.id')
             ->leftjoin('invoice i', 'i.id', 'ip.invoice_id')
             ->leftjoin('users u', 'u.id', 'i.user_id');
@@ -146,6 +146,9 @@ class paymentOperator extends entityDatabaseOperator{
         } else {
             $this->vault->where('p.user_id', $userEntity->id);
         }
+        if ($remoteOrderId > 0) {
+            $this->vault->where('p.remote_order_id', $remoteOrderId);
+        }
         return $this->vault
             ->orderBy('p.created', 'DESC')
             ->limit($limit)
@@ -153,6 +156,19 @@ class paymentOperator extends entityDatabaseOperator{
             ->fetchAll();
     }
 
+    public function getPaymentsForInvoiceIds($invoiceIds)
+    {
+        return $this->vault
+            ->select($this->dbTable . ' p')
+            ->fields('p.id, DATE_FORMAT(FROM_UNIXTIME(p.created), "%D %b %Y") as paymentDate, p.amount, p.status, i.line_items as lineItems, i.remote_order_id, p.provider, p.failure_reason, p.fraudulent, p.risk_level, i.id as invoice_id')
+            ->leftjoin('invoice_payment ip', 'ip.payment_id', 'p.id')
+            ->leftjoin('invoice i', 'i.id', 'ip.invoice_id')
+            ->where('i.id', $invoiceIds, 'IN')
+            ->orderBy('p.created', 'DESC')
+            ->execute()
+            ->fetchAll();
+    }
+
     public function getPaymentsForRemoteOrderIds($remoteOrderIds)
     {
         $results = $this->vault
